@@ -20,12 +20,9 @@ import shutil
 import sys
 import yaml
 
-from stevedore import extension
-
-from diskimage_builder.block_device.exception import \
-    BlockDeviceSetupException
+from diskimage_builder.block_device.config import config_tree_to_graph
+from diskimage_builder.block_device.config import create_graph
 from diskimage_builder.block_device.utils import exec_sudo
-from diskimage_builder.graph.digraph import Digraph
 
 
 logger = logging.getLogger(__name__)
@@ -119,30 +116,6 @@ class BlockDevice(object):
                         else:
                             v['label'] = "cloudimg-rootfs"
 
-    @staticmethod
-    def _config_tree_to_digraph(tconfig, plugin_manager):
-        """Converts a possible tree-like config into a complete digraph"""
-        dconfig = []
-        for config_entry in tconfig:
-            if len(config_entry) != 1:
-                logger.error("Invalid config entry: more than one key "
-                             "on top level [%s]" % config_entry)
-                raise BlockDeviceSetupException(
-                    "Top level config must contain exactly one key per entry")
-            logger.debug("Config entry [%s]" % config_entry)
-            config_key = list(config_entry)[0]
-            config_value = config_entry[config_key]
-            name = config_value['name'] \
-                   if 'name' in config_value else None
-            if config_key not in plugin_manager:
-                dconfig.append(config_entry)
-            else:
-                plugin_manager[config_key].plugin \
-                    .tree_config.config_tree_to_digraph(
-                        config_key, config_value, dconfig, name,
-                        plugin_manager)
-        return dconfig
-
     @staticmethod
     def _load_json(file_name):
         if os.path.exists(file_name):
@@ -166,9 +139,6 @@ class BlockDevice(object):
             self.params['build-dir'], "states/block-device")
         self.state_json_file_name \
             = os.path.join(self.state_dir, "state.json")
-        self.plugin_manager = extension.ExtensionManager(
-            namespace='diskimage_builder.block_device.plugin',
-            invoke_on_load=False)
         self.config_json_file_name \
             = os.path.join(self.state_dir, "config.json")
 
@@ -187,44 +157,8 @@ class BlockDevice(object):
         with open(self.state_json_file_name, "w") as fd:
             json.dump(state, fd)
 
-    def create_graph(self, config, default_config):
-        logger.debug("Create graph [%s]" % config)
-        # This is the directed graph of nodes: each parse method must
-        # add the appropriate nodes and edges.
-        dg = Digraph()
-
-        for config_entry in config:
-            if len(config_entry) != 1:
-                logger.error("Invalid config entry: more than one key "
-                             "on top level [%s]" % config_entry)
-                raise BlockDeviceSetupException(
-                    "Top level config must contain exactly one key per entry")
-            logger.debug("Config entry [%s]" % config_entry)
-            cfg_obj_name = list(config_entry.keys())[0]
-            cfg_obj_val = config_entry[cfg_obj_name]
-
-            # As the first step the configured objects are created
-            # (if it exists)
-            if cfg_obj_name not in self.plugin_manager:
-                logger.error("Configured top level element [%s] "
-                             "does not exists." % cfg_obj_name)
-                return 1
-            cfg_obj = self.plugin_manager[cfg_obj_name].plugin(
-                cfg_obj_val, default_config)
-            # At this point it is only possible to add the nodes:
-            # adding the edges needs all nodes first.
-            cfg_obj.insert_nodes(dg)
-
-        # Now that all the nodes exists: add also the edges
-        for node in dg.get_iter_nodes_values():
-            node.insert_edges(dg)
-
-        call_order = dg.topological_sort()
-        logger.debug("Call order [%s]" % (list(call_order)))
-        return dg, call_order
-
     def create(self, result, rollback):
-        dg, call_order = self.create_graph(self.config, self.params)
+        dg, call_order = create_graph(self.config, self.params)
         for node in call_order:
             node.create(result, rollback)
 
@@ -238,8 +172,7 @@ class BlockDevice(object):
         with open(self.params['config'], "rt") as config_fd:
             self.config = yaml.safe_load(config_fd)
         logger.debug("Config before merge [%s]" % self.config)
-        self.config = self._config_tree_to_digraph(self.config,
-                                                   self.plugin_manager)
+        self.config = config_tree_to_graph(self.config)
         logger.debug("Config before merge [%s]" % self.config)
         self._merge_into_config()
         logger.debug("Final config [%s]" % self.config)
@@ -382,7 +315,7 @@ class BlockDevice(object):
             return 0
 
         # Deleting must be done in reverse order
-        dg, call_order = self.create_graph(self.config, self.params)
+        dg, call_order = create_graph(self.config, self.params)
         reverse_order = reversed(call_order)
 
         if dg is None:
@@ -396,7 +329,7 @@ class BlockDevice(object):
         """Cleanup all remaining relicts - in good case"""
 
         # Deleting must be done in reverse order
-        dg, call_order = self.create_graph(self.config, self.params)
+        dg, call_order = create_graph(self.config, self.params)
         reverse_order = reversed(call_order)
 
         for node in reverse_order:
@@ -411,7 +344,7 @@ class BlockDevice(object):
         """Cleanup all remaining relicts - in case of an error"""
 
         # Deleting must be done in reverse order
-        dg, call_order = self.create_graph(self.config, self.params)
+        dg, call_order = create_graph(self.config, self.params)
         reverse_order = reversed(call_order)
 
         for node in reverse_order:
