@@ -6,20 +6,29 @@ set -o pipefail
 sudo apt-get update || true
 sudo apt-get install -y --force-yes \
         apt-transport-https \
+        bzip2 \
         debootstrap \
         docker.io \
         inetutils-ping \
         lsb-release \
         kpartx \
+        python-lzma \
         qemu-utils \
-        uuid-runtime || \
+        rpm \
+        uuid-runtime \
+        yum-utils || \
     sudo yum -y install \
+        bzip2 \
         debootstrap \
         docker \
         kpartx \
+        util-linux \
         qemu-img || \
     sudo emerge \
+        app-arch/bzip2 \
         app-emulation/qemu \
         dev-python/pyyaml \
         sys-block/parted \
-        sys-fs/multipath-tools
+        sys-fs/multipath-tools \
+        qemu-img \
+        yum-utils
